==> opennms-dao-mock-18.0.0-20160412.200246-199-sources.jar: org/opennms/netmgt/dao/mock/MockDistPollerDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.util.UUID;

import org.opennms.netmgt.dao.api.DistPollerDao;
import org.opennms.netmgt.model.OnmsDistPoller;

public class MockDistPollerDao extends AbstractMockDao<OnmsDistPoller,String> implements DistPollerDao {
    @Override
    protected void generateId(final OnmsDistPoller dp) {
        dp.setId(UUID.randomUUID().toString());
    }

    @Override
    protected String getId(final OnmsDistPoller dp) {
        return dp == null? null : dp.getId();
    }

    @Override
    public OnmsDistPoller whoami() {
        // Return the OnmsDistPoller with the default UUID
        return get(DEFAULT_DIST_POLLER_ID);
    }
}

==> opennms-dao-mock-19.0.0-20161003.014832-224-sources.jar: org/opennms/netmgt/dao/mock/MockDistPollerDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.util.UUID;

import org.opennms.netmgt.dao.api.DistPollerDao;
import org.opennms.netmgt.model.OnmsDistPoller;

public class MockDistPollerDao extends AbstractMockDao<OnmsDistPoller,String> implements DistPollerDao {
    @Override
    protected void generateId(final OnmsDistPoller dp) {
        dp.setId(UUID.randomUUID().toString());
    }

    @Override
    protected String getId(final OnmsDistPoller dp) {
        return dp == null? null : dp.getId();
    }

    @Override
    public OnmsDistPoller whoami() {
        final OnmsDistPoller defaultDistPoller = get(DEFAULT_DIST_POLLER_ID);
        if (defaultDistPoller != null) {
            return defaultDistPoller;
        }
        final OnmsDistPoller whoami = new OnmsDistPoller();
        whoami.setId(DEFAULT_DIST_POLLER_ID);
        whoami.setLabel("localhost");
        whoami.setLocation("localhost");
        return whoami;
    }
}
